@@ -41,6 +41,7 @@ from .type_defs import (
     DeleteOutboundCrossClusterSearchConnectionResponseTypeDef,
     DeletePackageResponseTypeDef,
     DescribeDomainAutoTunesResponseTypeDef,
+    DescribeDomainChangeProgressResponseTypeDef,
     DescribeElasticsearchDomainConfigResponseTypeDef,
     DescribeElasticsearchDomainResponseTypeDef,
     DescribeElasticsearchDomainsResponseTypeDef,
@@ -116,7 +117,7 @@ class Exceptions:
 
 class ElasticsearchServiceClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html)
     """
 
@@ -135,7 +136,7 @@ class ElasticsearchServiceClient(BaseClient):
         Allows the destination domain owner to accept an inbound cross-cluster search
         connection request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.accept_inbound_cross_cluster_search_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.accept_inbound_cross_cluster_search_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#accept_inbound_cross_cluster_search_connection)
         """
 
@@ -143,7 +144,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
         Attaches tags to an existing Elasticsearch domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.add_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.add_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#add_tags)
         """
 
@@ -153,7 +154,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
         Associates a package with an Amazon ES domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.associate_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.associate_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#associate_package)
         """
 
@@ -161,7 +162,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#can_paginate)
         """
 
@@ -171,7 +172,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
         Cancels a scheduled service software update for an Amazon ES domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.cancel_elasticsearch_service_software_update)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.cancel_elasticsearch_service_software_update)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#cancel_elasticsearch_service_software_update)
         """
 
@@ -198,7 +199,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
         Creates a new Elasticsearch domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.create_elasticsearch_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.create_elasticsearch_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#create_elasticsearch_domain)
         """
 
@@ -213,7 +214,7 @@ class ElasticsearchServiceClient(BaseClient):
         Creates a new cross-cluster search connection from a source domain to a
         destination domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.create_outbound_cross_cluster_search_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.create_outbound_cross_cluster_search_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#create_outbound_cross_cluster_search_connection)
         """
 
@@ -228,7 +229,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
         Create a package for use with Amazon ES domains.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.create_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.create_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#create_package)
         """
 
@@ -238,7 +239,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
         Permanently deletes the specified Elasticsearch domain and all of its data.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#delete_elasticsearch_domain)
         """
 
@@ -247,7 +248,7 @@ class ElasticsearchServiceClient(BaseClient):
         Deletes the service-linked role that Elasticsearch Service uses to manage and
         maintain VPC domains.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_service_role)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_service_role)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#delete_elasticsearch_service_role)
         """
 
@@ -258,7 +259,7 @@ class ElasticsearchServiceClient(BaseClient):
         Allows the destination domain owner to delete an existing inbound cross-cluster
         search connection.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.delete_inbound_cross_cluster_search_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.delete_inbound_cross_cluster_search_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#delete_inbound_cross_cluster_search_connection)
         """
 
@@ -269,7 +270,7 @@ class ElasticsearchServiceClient(BaseClient):
         Allows the source domain owner to delete an existing outbound cross-cluster
         search connection.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.delete_outbound_cross_cluster_search_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.delete_outbound_cross_cluster_search_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#delete_outbound_cross_cluster_search_connection)
         """
 
@@ -277,7 +278,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
         Delete the package.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.delete_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.delete_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#delete_package)
         """
 
@@ -288,10 +289,21 @@ class ElasticsearchServiceClient(BaseClient):
         Provides scheduled Auto-Tune action details for the Elasticsearch domain, such
         as Auto-Tune action type, description, severity, and scheduled date.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.describe_domain_auto_tunes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.describe_domain_auto_tunes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_domain_auto_tunes)
         """
 
+    def describe_domain_change_progress(
+        self, *, DomainName: str, ChangeId: str = ...
+    ) -> DescribeDomainChangeProgressResponseTypeDef:
+        """
+        Returns information about the current blue/green deployment happening on a
+        domain, including a change ID, status, and progress stages.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.describe_domain_change_progress)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_domain_change_progress)
+        """
+
     def describe_elasticsearch_domain(
         self, *, DomainName: str
     ) -> DescribeElasticsearchDomainResponseTypeDef:
@@ -299,7 +311,7 @@ class ElasticsearchServiceClient(BaseClient):
         Returns domain configuration information about the specified Elasticsearch
         domain, including the domain ID, domain endpoint, and domain ARN.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_elasticsearch_domain)
         """
 
@@ -311,7 +323,7 @@ class ElasticsearchServiceClient(BaseClient):
         domain, such as the state, creation date, update version, and update date for
         cluster options.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_elasticsearch_domain_config)
         """
 
@@ -322,7 +334,7 @@ class ElasticsearchServiceClient(BaseClient):
         Returns domain configuration information about the specified Elasticsearch
         domains, including the domain ID, domain endpoint, and domain ARN.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domains)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domains)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_elasticsearch_domains)
         """
 
@@ -336,7 +348,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
         Describe Elasticsearch Limits for a given InstanceType and ElasticsearchVersion.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_instance_type_limits)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_instance_type_limits)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_elasticsearch_instance_type_limits)
         """
 
@@ -350,7 +362,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
         Lists all the inbound cross-cluster search connections for a destination domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.describe_inbound_cross_cluster_search_connections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.describe_inbound_cross_cluster_search_connections)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_inbound_cross_cluster_search_connections)
         """
 
@@ -364,7 +376,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
         Lists all the outbound cross-cluster search connections for a source domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.describe_outbound_cross_cluster_search_connections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.describe_outbound_cross_cluster_search_connections)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_outbound_cross_cluster_search_connections)
         """
 
@@ -378,7 +390,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
         Describes all packages available to Amazon ES.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.describe_packages)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.describe_packages)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_packages)
         """
 
@@ -392,7 +404,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
         Lists available reserved Elasticsearch instance offerings.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instance_offerings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instance_offerings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_reserved_elasticsearch_instance_offerings)
         """
 
@@ -406,7 +418,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
         Returns information about reserved Elasticsearch instances for this account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instances)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_reserved_elasticsearch_instances)
         """
 
@@ -416,7 +428,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
         Dissociates a package from the Amazon ES domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.dissociate_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.dissociate_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#dissociate_package)
         """
 
@@ -430,7 +442,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#generate_presigned_url)
         """
 
@@ -440,7 +452,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
         Returns a list of upgrade compatible Elastisearch versions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.get_compatible_elasticsearch_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.get_compatible_elasticsearch_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#get_compatible_elasticsearch_versions)
         """
 
@@ -451,7 +463,7 @@ class ElasticsearchServiceClient(BaseClient):
         Returns a list of versions of the package, along with their creation time and
         commit message.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.get_package_version_history)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.get_package_version_history)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#get_package_version_history)
         """
 
@@ -462,7 +474,7 @@ class ElasticsearchServiceClient(BaseClient):
         Retrieves the complete history of the last 10 upgrades that were performed on
         the domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.get_upgrade_history)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.get_upgrade_history)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#get_upgrade_history)
         """
 
@@ -471,7 +483,7 @@ class ElasticsearchServiceClient(BaseClient):
         Retrieves the latest status of the last upgrade or upgrade eligibility check
         that was performed on the domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.get_upgrade_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.get_upgrade_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#get_upgrade_status)
         """
 
@@ -482,7 +494,7 @@ class ElasticsearchServiceClient(BaseClient):
         Returns the name of all Elasticsearch domains owned by the current user's
         account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.list_domain_names)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.list_domain_names)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#list_domain_names)
         """
 
@@ -492,7 +504,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
         Lists all Amazon ES domains associated with the package.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.list_domains_for_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.list_domains_for_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#list_domains_for_package)
         """
 
@@ -509,7 +521,7 @@ class ElasticsearchServiceClient(BaseClient):
         ElasticsearchVersion See also: [AWS API
         Documentation](https://docs.aws.amazon.com/goto/WebAPI/es-2015-01-01/ListElasticsearchInstanceTypes).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_instance_types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_instance_types)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#list_elasticsearch_instance_types)
         """
 
@@ -520,7 +532,7 @@ class ElasticsearchServiceClient(BaseClient):
         List all supported Elasticsearch versions See also: [AWS API
         Documentation](https://docs.aws.amazon.com/goto/WebAPI/es-2015-01-01/ListElasticsearchVersions).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#list_elasticsearch_versions)
         """
 
@@ -530,7 +542,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
         Lists all packages associated with the Amazon ES domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.list_packages_for_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.list_packages_for_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#list_packages_for_domain)
         """
 
@@ -538,7 +550,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
         Returns all tags for the given Elasticsearch domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.list_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.list_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#list_tags)
         """
 
@@ -552,7 +564,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
         Allows you to purchase reserved Elasticsearch instances.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.purchase_reserved_elasticsearch_instance_offering)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.purchase_reserved_elasticsearch_instance_offering)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#purchase_reserved_elasticsearch_instance_offering)
         """
 
@@ -563,7 +575,7 @@ class ElasticsearchServiceClient(BaseClient):
         Allows the destination domain owner to reject an inbound cross-cluster search
         connection request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.reject_inbound_cross_cluster_search_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.reject_inbound_cross_cluster_search_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#reject_inbound_cross_cluster_search_connection)
         """
 
@@ -571,7 +583,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
         Removes the specified set of tags from the specified Elasticsearch domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.remove_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.remove_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#remove_tags)
         """
 
@@ -581,7 +593,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
         Schedules a service software update for an Amazon ES domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.start_elasticsearch_service_software_update)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.start_elasticsearch_service_software_update)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#start_elasticsearch_service_software_update)
         """
 
@@ -608,7 +620,7 @@ class ElasticsearchServiceClient(BaseClient):
         Modifies the cluster configuration of the specified Elasticsearch domain,
         setting as setting the instance type and the number of instances.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.update_elasticsearch_domain_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.update_elasticsearch_domain_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#update_elasticsearch_domain_config)
         """
 
@@ -623,7 +635,7 @@ class ElasticsearchServiceClient(BaseClient):
         """
         Updates a package for use with Amazon ES domains.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.update_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.update_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#update_package)
         """
 
@@ -634,7 +646,7 @@ class ElasticsearchServiceClient(BaseClient):
         Allows you to either upgrade your domain or perform an Upgrade eligibility check
         to a compatible Elasticsearch version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Client.upgrade_elasticsearch_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Client.upgrade_elasticsearch_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#upgrade_elasticsearch_domain)
         """
 
@@ -643,7 +655,7 @@ class ElasticsearchServiceClient(BaseClient):
         self, operation_name: Literal["describe_reserved_elasticsearch_instance_offerings"]
     ) -> DescribeReservedElasticsearchInstanceOfferingsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstanceOfferings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstanceOfferings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/paginators.html#describereservedelasticsearchinstanceofferingspaginator)
         """
 
@@ -652,7 +664,7 @@ class ElasticsearchServiceClient(BaseClient):
         self, operation_name: Literal["describe_reserved_elasticsearch_instances"]
     ) -> DescribeReservedElasticsearchInstancesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstances)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/paginators.html#describereservedelasticsearchinstancespaginator)
         """
 
@@ -661,7 +673,7 @@ class ElasticsearchServiceClient(BaseClient):
         self, operation_name: Literal["get_upgrade_history"]
     ) -> GetUpgradeHistoryPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Paginator.GetUpgradeHistory)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Paginator.GetUpgradeHistory)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/paginators.html#getupgradehistorypaginator)
         """
 
@@ -670,7 +682,7 @@ class ElasticsearchServiceClient(BaseClient):
         self, operation_name: Literal["list_elasticsearch_instance_types"]
     ) -> ListElasticsearchInstanceTypesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchInstanceTypes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchInstanceTypes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/paginators.html#listelasticsearchinstancetypespaginator)
         """
 
@@ -679,6 +691,6 @@ class ElasticsearchServiceClient(BaseClient):
         self, operation_name: Literal["list_elasticsearch_versions"]
     ) -> ListElasticsearchVersionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchVersions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchVersions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/paginators.html#listelasticsearchversionspaginator)
         """
